==> qmmp-plugin-pack-0.10.0.tar.bz2: qmmp-plugin-pack-0.10.0/src/Effect/srconverter/translations/srconverter_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="32"/>
        <source>SRC Plugin</source>
        <translation>SRC-Modul</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="53"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>Über Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="54"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Qmmp Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Einstellungen Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Abtastrate (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Interpolation:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>Sinc (hohe Qualität)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Sinc (mittlere Qualität)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Schnellste Sinc-Interpolation</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>Zero-Order-Hold (ZOH)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>Linear</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-0.10.3.tar.bz2: qmmp-plugin-pack-0.10.3/src/Effect/srconverter/translations/srconverter_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="32"/>
        <source>SRC Plugin</source>
        <translation>SRC-Modul</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="53"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>Über Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="54"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Qmmp Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Einstellungen Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Abtastrate (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Interpolationseinheit:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>Beste Sinc-Interpolation</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Mittlere Sinc-Interpolation</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Schnellste Sinc-Interpolation</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>ZOH-Interpolation</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>Lineare Interpolation</translation>
    </message>
</context>
</TS>
